@@ -7,7 +7,7 @@ import perpy as py
 from ctypes import *
 
 def version():
-    version = '0.2.4'
+    version = '0.2.7'
     print('||====================||')
     print('||        PerPy       ||')
     print('||====================||  Version: ' + version)
@@ -143,7 +143,10 @@ def dist(x, y):
     try:
         lib = cdll.LoadLibrary(os.path.realpath(__file__)[:-11]+ 'ops/cpu/dist.so')
     except:
-        lib = cdll.LoadLibrary(os.path.realpath(__file__)[:-11] + 'ops/cpu/dist.dll')
+        try:
+            lib = CDLL(os.path.realpath(__file__)[:-11] + 'ops/cpu/dist.dll')
+        except:
+            lib = CDLL(os.path.realpath(__file__)[:-11] + 'ops/cpu/dist.dll')
     num = x.shape[0] #
     x = (c_double * num)(*x)
     y = (c_double * num)(*y)
